@@ -7,7 +7,7 @@ package Lemonldap::NG::Portal::AuthMulti;
 
 use Lemonldap::NG::Portal::_Multi;    #inherits
 
-our $VERSION = '1.2.2_01';
+our $VERSION = '1.4.10';
 
 sub authInit {
     my $self = shift;
@@ -21,6 +21,8 @@ sub extractFormInfo {
 
 sub setAuthSessionInfo {
     my $self = shift;
+    $self->{sessionInfo}->{_authMulti} =
+      $self->{_multi}->{stack}->[0]->[0]->{n};
     return $self->_multi->try( 'setAuthSessionInfo', 0 );
 }
 
@@ -34,6 +36,11 @@ sub authFinish {
     return $self->_multi->try( 'authFinish', 0 );
 }
 
+sub authPostStore {
+    my $self = shift;
+    return $self->_multi->try( 'authPostStore', 0 );
+}
+
 sub authLogout {
     my $self = shift;
     return $self->_multi->try( 'authLogout', 0 );
@@ -41,17 +48,17 @@ sub authLogout {
 
 sub authForce {
     my $self = shift;
-    return $self->_multi->try( 'authForce', 0 );
+    $self->_sub('authInit');
+    my $s    = $self->{_multi}->{last}->[0] . "::authForce";
+    return &{$s}($self);
 }
 
 sub getDisplayType {
     my $self = shift;
-    my $s =
-        "Lemonldap::NG::Portal::Auth"
-      . $self->{_multi}->{last}->[0]
-      . "::getDisplayType";
+    my $s    = $self->{_multi}->{last}->[0] . "::getDisplayType";
     return &{$s};
 }
 
+
 1;
 
