@@ -11,7 +11,7 @@ use Lemonldap::NG::Portal::Simple;
 use Lemonldap::NG::Portal::_SAML;    #inherits
 use Lemonldap::NG::Common::Conf::SAML::Metadata;
 
-our $VERSION = '1.4.2';
+our $VERSION = '1.4.10';
 our @ISA     = qw(Lemonldap::NG::Portal::_SAML);
 
 ## @apmethod int authInit()
@@ -1066,8 +1066,8 @@ sub setAuthSessionInfo {
             # Extract fields from exportedAttr value
             my ( $mandatory, $name, $format, $friendly_name ) =
               split( /;/,
-                $self->{samlIDPMetaDataExportedAttributes}->{$idpConfKey}
-                  ->{$_} );
+                $self->{samlIDPMetaDataExportedAttributes}->{$idpConfKey}->{$_}
+              );
 
             # Try to get value
             my $value =
@@ -1434,9 +1434,16 @@ sub authForce {
 }
 
 ## @apmethod boolean authFinish()
-# Associate NameID and SessionIndex to a local session
+# Do nothing
 # @return Lemonldap::NG::Portal error code
 sub authFinish {
+    PE_OK;
+}
+
+## @apmethod boolean authPostStore()
+# Associate NameID and SessionIndex to a local session
+# @return Lemonldap::NG::Portal error code
+sub authPostStore {
     my $self = shift;
     my %h;
 
