@@ -7,8 +7,9 @@
 package Lemonldap::NG::Portal::_Choice;
 
 use Lemonldap::NG::Portal::Simple;
+use Scalar::Util 'weaken';
 
-our $VERSION = '1.3.0';
+our $VERSION = '1.4.9';
 
 ## @cmethod Lemonldap::NG::Portal::_Choice new(Lemonldap::NG::Portal::Simple portal)
 # Constructor
@@ -19,6 +20,7 @@ sub new {
 
     # Create object with portal parameter
     my $self = bless { p => $portal }, $class;
+    weaken $self->{p};
 
     # Recover authChoice from session
     $portal->{_authChoice} ||= $portal->{sessionInfo}->{_authChoice};
@@ -32,6 +34,13 @@ sub new {
         $portal->{_authChoice} = "";
     }
 
+    # Special workaround for Captcha
+    # Init Captcha to have it displayed even if no choice already done
+    if ( $portal->{captcha_login_enabled} ) {
+        eval { $portal->initCaptcha(); };
+        $portal->lmLog( "Can't init captcha: $@", "error" ) if $@;
+    }
+
     # Special workaround for SAML
     # because we cannot easily set SSO return URL
     # and SLO URL with authChoice parameter
@@ -187,7 +196,8 @@ sub _buildAuthLoop {
         if ( $auth and $userDB and $passwordDB ) {
 
             # Default URL
-            $url ||= "#";
+            $url = ( defined $url ? $url .= $ENV{'REQUEST_URI'} : '#' );
+            $self->lmLog( "Use URL $url", 'debug' );
 
             # Options to store in the loop
             my $optionsLoop =
