@@ -13,14 +13,14 @@ package Lemonldap::NG::Portal::_Multi;
 use Lemonldap::NG::Portal::Simple;
 use Scalar::Util 'weaken';
 
-our $VERSION = '1.4.0';
+our $VERSION = '1.4.8';
 
 ## @cmethod Lemonldap::NG::Portal::_Multi new(Lemonldap::NG::Portal::Simple portal)
 # Constructor
 # @param $portal Lemonldap::NG::Portal::Simple object
 # @return new Lemonldap::NG::Portal::_Multi object
 sub new {
-    my ( $class, $portal ) = splice @_;
+    my ( $class, $portal ) = @_;
     my $self = bless { p => $portal, res => PE_NOSCHEME }, $class;
     weaken $self->{p};
 
@@ -35,6 +35,7 @@ sub new {
             my ( $mod, $cond ) = ( $1, $2 );
             my $name = $mod;
             $mod =~ s/#(.*)$//;
+            my $shortname = $mod;
             $cond = 1 unless ( defined $cond );
             $mod = "Lemonldap::NG::Portal::" . [ 'Auth', 'UserDB' ]->[$i] . $mod
               unless ( $mod =~ /::/ );
@@ -42,7 +43,7 @@ sub new {
             $portal->abort( 'Bad configuration', "Unable to load $mod" )
               unless $self->{p}->loadModule($mod);
             push @{ $self->{stack}->[$i] },
-              { m => $mod, c => $cond, n => $name };
+              { m => $mod, c => $cond, n => $name, s => $shortname };
         }
 
         # Override portal settings
@@ -64,7 +65,7 @@ sub new {
 # @param type 0 for authentication, 1 for userDB
 # @return Lemonldap::NG::Portal error code returned by method $sub
 sub try {
-    my ( $self, $sub, $type ) = splice @_;
+    my ( $self, $sub, $type ) = @_;
     my $res;
     my $s   = $self->{stack}->[$type]->[0]->{m} . "::$sub";
     my $old = $self->{stack}->[$type]->[0]->{n};
@@ -109,7 +110,7 @@ sub try {
 # @param type 0 for authentication, 1 for userDB
 # return true if an other module is available
 sub next {
-    my ( $self, $type ) = splice @_;
+    my ( $self, $type ) = @_;
 
     if ( $self->{stack}->[$type]->[0]->{n} eq
             $self->{stack}->[ 1 - $type ]->[0]->{n}
@@ -134,13 +135,14 @@ sub next {
 # @param $sub name of the method who has failed
 # @return Lemonldap::NG::Portal error code
 sub replay {
-    my ( $self, $sub ) = splice @_;
+    my ( $self, $sub ) = @_;
     my @subs = ();
     $self->{p}->lmLog( "Replay all methods until sub $sub", 'debug' );
 
     foreach (
         qw(authInit extractFormInfo userDBInit getUser setAuthSessionInfo
-        setSessionInfo setGroups authenticate authFinish)
+        setSessionInfo setMacros setGroups setPersistentSessionInfo
+        setLocalGroups authenticate authFinish)
       )
     {
         push @subs, $_;
